<?php

namespace Litecms\RankSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\RankSetting\Models\RankSetting;

class RankSettingPolicy
{

    /**
     * Determine if the given user can view the rank_setting.
     *
     * @param UserPolicy $user
     * @param RankSetting $rank_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, RankSetting $rank_setting)
    {
        if ($user->canDo('rank_setting.rank_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $rank_setting->user_id == user_id() && $rank_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a rank_setting.
     *
     * @param UserPolicy $user
     * @param RankSetting $rank_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('rank_setting.rank_setting.create');
    }

    /**
     * Determine if the given user can update the given rank_setting.
     *
     * @param UserPolicy $user
     * @param RankSetting $rank_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, RankSetting $rank_setting)
    {
        if ($user->canDo('rank_setting.rank_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $rank_setting->user_id == user_id() && $rank_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given rank_setting.
     *
     * @param UserPolicy $user
     * @param RankSetting $rank_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RankSetting $rank_setting)
    {
        return $rank_setting->user_id == user_id() && $rank_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given rank_setting.
     *
     * @param UserPolicy $user
     * @param RankSetting $rank_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RankSetting $rank_setting)
    {
        if ($user->canDo('rank_setting.rank_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given rank_setting.
     *
     * @param UserPolicy $user
     * @param RankSetting $rank_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RankSetting $rank_setting)
    {
        if ($user->canDo('rank_setting.rank_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
