<?php

namespace Litecms\RankSetting\Providers;

use Illuminate\Support\ServiceProvider;

class RankSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'rank_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'rank_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerRankSetting();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerRankSetting()
    {
        $this->app->bind('rank_setting', function($app) {
            return new RankSetting($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('RankSetting', 'Lavalite\RankSetting\Facades\RankSetting');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.rank_setting', function ($app) {
            return $this->app->make('Litecms\RankSetting\RankSetting');
        });

                // Bind RankSetting to repository
        $this->app->bind(
            'Litecms\RankSetting\Interfaces\RankSettingRepositoryInterface',
            \Litecms\RankSetting\Repositories\Eloquent\RankSettingRepository::class
        );

        $this->app->register(\Litecms\RankSetting\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\RankSetting\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\RankSetting\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and rank_setting's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/rank_setting.php', 'rank_setting'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeRankSetting::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.rank_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/rank_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/rank_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/rank_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
